@@ -1,6 +1,6 @@
 import pytest
 from ssb_altinn3_util.models.altinn3_cloud_event import Altinn3CloudEvent
-
+from altinn3_test_lib.utils.fileutils import read_file_lines_into_object
 
 @pytest.fixture(scope="function")
 def altinn_event_factory():
@@ -24,3 +24,18 @@ def altinn_event_factory():
         )
         return event
     return create_test_event
+
+
+@pytest.fixture(scope="function")
+def create_instance():
+    return read_file_lines_into_object("instance.json")
+
+
+@pytest.fixture(scope="function")
+def create_instance_json_out():
+    return read_file_lines_into_object("instance_json_out.json")
+
+
+@pytest.fixture(scope="function")
+def create_instance_json_in():
+    return read_file_lines_into_object("instance_json_in.json")
