@@ -26,5 +26,5 @@ def basic_file_factory():
 
 
 @pytest.fixture(scope="function")
-def create_instance():
-    return read_file_lines_into_object("instance.json")
+def create_simple_prefill():
+    return read_file_lines_into_object("simple_prefill.txt")
\ No newline at end of file
